==> haskell-hpack-0.35.5-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.5
visibility:           public
id:                   hpack-0.35.5-4ts2XDK4T6tAmNUUmRCEjo
key:                  hpack-0.35.5-4ts2XDK4T6tAmNUUmRCEjo
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  ab5772852bde8d5aaede0a1e5746e20e
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.5-4ts2XDK4T6tAmNUUmRCEjo
depends:
    Cabal-3.8.1.0 Glob-0.10.2-Hob8DYnGL6h4dNEc34Y4vH
    aeson-2.1.2.1-BWqAP5DPS0iMNSAJtMWSf base-4.17.2.1
    bifunctors-5.6.2-5yBt2VZqrV2LUbi3Oa675Z bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.2-Kg4v6mjTpaO8L2gZHA2PVC
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.19-LKlU3HcOEMNION0MdQYtj
    http-client-tls-0.3.6.4-1iaAAi64BfdGALlJ7qoOys
    http-types-0.12.4-JotGc98QwUtHuX8PPdlxoe
    infer-license-0.2.0-AxdQ4gMW6QkFkQ9sI34uYW pretty-1.1.3.6
    scientific-0.3.8.0-Lr1UPzAneM96vFGoFLDTYK text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-G9Xtyt8hv5K8HhfrH8JX1r
    vector-0.13.2.0-K0fBmK5qd7y3388236ZS0A
    yaml-0.11.11.2-E2y2ob5lfUes8QJFxXIpl

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.35.5-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hpack
version:              0.35.5
visibility:           public
id:                   hpack-0.35.5-jza8IF2ZhK41QdgCBbuxE
key:                  hpack-0.35.5-jza8IF2ZhK41QdgCBbuxE
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
homepage:             https://github.com/sol/hpack#readme
synopsis:             A modern format for Haskell packages
description:          See README at <https://github.com/sol/hpack#readme>
category:             Development
abi:                  ef611790b97b2dfd5dcc0d95c93ba804
exposed:              True
exposed-modules:
    Hpack Hpack.Config Hpack.Error Hpack.Render Hpack.Yaml

hidden-modules:
    Data.Aeson.Config.FromValue Data.Aeson.Config.Key
    Data.Aeson.Config.KeyMap Data.Aeson.Config.Parser
    Data.Aeson.Config.Types Data.Aeson.Config.Util Hpack.CabalFile
    Hpack.Defaults Hpack.Haskell Hpack.License Hpack.Module
    Hpack.Options Hpack.Render.Dsl Hpack.Render.Hints
    Hpack.Syntax.BuildTools Hpack.Syntax.Defaults
    Hpack.Syntax.Dependencies Hpack.Syntax.DependencyVersion
    Hpack.Syntax.Git Hpack.Syntax.ParseDependencies Hpack.Utf8
    Hpack.Util Imports Path Paths_hpack

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hpack-0.35.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hpack
hs-libraries:         HShpack-0.35.5-jza8IF2ZhK41QdgCBbuxE
depends:
    Cabal-3.8.1.0 Glob-0.10.2-4hGAIIuIwc1EHm05XfQPMH
    aeson-2.1.2.1-JD8QPsoBF4NC1qVY6ch6us base-4.17.2.1
    bifunctors-5.6.2-1Z7sUBZd1mCH05DXW3V4EJ bytestring-0.11.5.3
    containers-0.6.7 crypton-1.0.2-8dVLH0jap0Gp5bokZc6Zp
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    http-client-0.7.19-IOiFZdMrMxf1FD0Q8GvNdl
    http-client-tls-0.3.6.4-5Ho7Yjl7j7WL01BIog0cDK
    http-types-0.12.4-BvZSYA7IliCW0EQtF31VI
    infer-license-0.2.0-1UKCziqArzACGAMEKtloHK pretty-1.1.3.6
    scientific-0.3.8.0-JrlaAXGfnydA9ZtLsuTElg text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-ASGEyX3xTBf3ZK5sYSGlF8
    vector-0.13.2.0-L6HpF7nmtGm1K7R40olL6U
    yaml-0.11.11.2-37tw4FuYjIR6RRod391CFN

haddock-interfaces:   /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html:         /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
